@@ -6,10 +6,12 @@ from ..logger import Logger
 from .report import QaseReport
 from .testops import QaseTestOps
 
-from ..models import InternalResult, Result, Attachment, Runtime
+from ..models import Result, Attachment, Runtime
 from ..models.config.qaseconfig import Mode
 from typing import Union, List
 
+from ..util import get_host_info
+
 """
     CoreReporter is a facade for all reporters and it is used to initialize and manage them.
     It is also used to pass configuration and logger to reporters, handle fallback logic and error handling.
@@ -17,7 +19,7 @@ from typing import Union, List
 
 
 class QaseCoreReporter:
-    def __init__(self, config: ConfigManager):
+    def __init__(self, config: ConfigManager, framework: Union[str, None] = None, reporter_name: Union[str, None] = None):
         config.validate_config()
         self.config = config.config
         self.logger = Logger(self.config.debug)
@@ -30,6 +32,9 @@ class QaseCoreReporter:
 
         self.logger.log_debug(f"Config: {self.config}")
 
+        host_data = get_host_info(framework, reporter_name)
+        self.logger.log_debug(f"Host data: {host_data}")
+
         # Reading reporter mode from config file
         mode = self.config.mode
 
@@ -79,20 +84,8 @@ class QaseCoreReporter:
             try:
                 ts = time.time()
                 self.logger.log_debug(f"Adding result {result}")
-                ids = result.get_testops_id()
 
-                if ids is None:
-                    int_result = InternalResult.convert_from_result(result)
-                    self.reporter.add_result(int_result)
-                else:
-                    first = True
-                    for testops_id in ids:
-                        int_result = InternalResult.convert_from_result(result, testops_id)
-                        if not first:
-                            int_result.execution.duration = 0
-                        else:
-                            first = False
-                        self.reporter.add_result(int_result)
+                self.reporter.add_result(result)
 
                 self.logger.log_debug(f"Result {result.get_title()} added")
                 self.overhead += time.time() - ts
